@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: manages UDM modules
@@ -47,7 +46,6 @@ import traceback
 from functools import reduce
 from json import load
 
-import six
 from ldap import NO_SUCH_OBJECT, LDAPError
 from ldap.dn import explode_dn
 from ldap.filter import filter_format
@@ -74,8 +72,6 @@ __bind_function = None
 __bind_hash = None
 _licenseCheck = 0
 
-getfullargspec = getattr(inspect, 'getfullargspec', getattr(inspect, 'getargspec', None))
-
 
 def calculate_bind_hash(request):
     return hash((request.username, request.password, request.auth_type))
@@ -125,14 +121,14 @@ class UMCError(UMC_Error):
         self._is_master = ucr.get('server/role') == 'domaincontroller_master'
         self._updates_available = ucr.is_true('update/available')
         self._fqdn = '%(hostname)s.%(domainname)s' % ucr
-        super(UMCError, self).__init__('\n'.join(self._error_msg()), **kwargs)
+        super().__init__('\n'.join(self._error_msg()), **kwargs)
 
     def _error_msg(self):
         # return a generator or a list of strings which are concatenated by a newline
         yield ''
 
 
-class AppAttributes(object):
+class AppAttributes:
     FNAME = '/var/lib/univention-appcenter/attributes/mapping.json'
     _cache = None
 
@@ -155,7 +151,7 @@ class AppAttributes(object):
         try:
             with open(cls.FNAME) as fd:
                 cache = load(fd)
-        except EnvironmentError:
+        except OSError:
             MODULE.warn('Error reading %s' % cls.FNAME)
             cache = {}
         except ValueError:
@@ -212,7 +208,7 @@ class AppAttributes(object):
     def _flatten(cls, attrs):
         ret = []
         for sublist in attrs:
-            if isinstance(sublist, (list, tuple)):
+            if isinstance(sublist, list | tuple):
                 ret.extend(cls._flatten(sublist))
             else:
                 ret.append(sublist)
@@ -230,7 +226,7 @@ class AppAttributes(object):
                 cls._filter_attrs(_layout, attrs_to_remove)
         elif isinstance(layout, list):
             for _layout in layout:
-                if isinstance(_layout, (dict, list)):
+                if isinstance(_layout, dict | list):
                     cls._filter_attrs(_layout, attrs_to_remove)
             for attr in attrs_to_remove:
                 try:
@@ -277,7 +273,7 @@ class UserWithoutDN(UMCError):
 
     def __init__(self, username):
         self._username = username
-        super(UserWithoutDN, self).__init__()
+        super().__init__()
 
     def _error_msg(self):
         yield _('The LDAP DN of the user %s could not be determined.') % (self._username,)
@@ -297,7 +293,7 @@ class UserWithoutDN(UMCError):
 class LDAP_AuthenticationFailed(UMCError):
 
     def __init__(self):
-        super(LDAP_AuthenticationFailed, self).__init__(status=401)
+        super().__init__(status=401)
 
     def _error_msg(self):
         yield _('Authentication failed')
@@ -307,7 +303,7 @@ class ObjectDoesNotExist(UMCError):
 
     def __init__(self, ldap_dn):
         self.ldap_dn = ldap_dn
-        super(ObjectDoesNotExist, self).__init__()
+        super().__init__()
 
     @LDAP_Connection
     def _ldap_object_exists(self, ldap_connection=None, ldap_position=None):
@@ -345,7 +341,7 @@ class NoIpLeft(UMCError):
             self.network_name = udm.uldap.explodeDn(ldap_dn, True)[0]
         except IndexError:
             self.network_name = ldap_dn
-        super(NoIpLeft, self).__init__()
+        super().__init__()
 
     def _error_msg(self):
         yield _('Failed to automatically assign an IP address.')
@@ -356,13 +352,13 @@ class NoIpLeft(UMCError):
 class SearchTimeoutError(UMC_Error):
 
     def __init__(self):
-        super(SearchTimeoutError, self).__init__(_('The query you have entered timed out. Please narrow down your search by specifying more query parameters'))
+        super().__init__(_('The query you have entered timed out. Please narrow down your search by specifying more query parameters'))
 
 
 class SearchLimitReached(UMC_Error):
 
     def __init__(self):
-        super(SearchLimitReached, self).__init__(_('The query you have entered yields too many matching entries. Please narrow down your search by specifying more query parameters. The current size limit of %s can be configured with the UCR variable directory/manager/web/sizelimit.') % ucr.get('directory/manager/web/sizelimit', '2000'))
+        super().__init__(_('The query you have entered yields too many matching entries. Please narrow down your search by specifying more query parameters. The current size limit of %s can be configured with the UCR variable directory/manager/web/sizelimit.') % ucr.get('directory/manager/web/sizelimit', '2000'))
 
 
 class UDM_Error(Exception):
@@ -376,7 +372,7 @@ class UDM_Error(Exception):
 
     def reraise(self):
         if self.exc_info and self.exc_info != (None, None, None):
-            six.reraise(self.__class__, self, self.exc_info[2])
+            raise self.with_traceback(self.exc_info[2])
         raise self
 
 
@@ -406,7 +402,7 @@ class UDM_ModuleCache(dict):
 _module_cache = UDM_ModuleCache()
 
 
-class UDM_Module(object):
+class UDM_Module:
     """Wraps UDM modules to provide a simple access to the properties and functions"""
 
     def __init__(self, module, force_reload=False, ldap_connection=None, ldap_position=None):
@@ -498,7 +494,7 @@ class UDM_Module(object):
                 raise UMC_Error(_('Property %s not found') % property_name)
 
             # check each element if 'value' is a list
-            if isinstance(value, (tuple, list)) and property_obj.multivalue:
+            if isinstance(value, tuple | list) and property_obj.multivalue:
                 if not value and not property_obj.required:
                     MODULE.info('Setting of property ignored (is empty)')
                     if property_name in obj.info:
@@ -684,13 +680,13 @@ class UDM_Module(object):
                     result = []
                 else:
                     if simple_attrs is not None:
-                        result = ldap_connection.search(filter=six.text_type(lookup_filter), base=container, scope=scope, sizelimit=sizelimit, attr=simple_attrs, serverctrls=serverctrls, response=response)
+                        result = ldap_connection.search(filter=str(lookup_filter), base=container, scope=scope, sizelimit=sizelimit, attr=simple_attrs, serverctrls=serverctrls, response=response)
                     else:
-                        result = ldap_connection.searchDn(filter=six.text_type(lookup_filter), base=container, scope=scope, sizelimit=sizelimit, serverctrls=serverctrls, response=response)
+                        result = ldap_connection.searchDn(filter=str(lookup_filter), base=container, scope=scope, sizelimit=sizelimit, serverctrls=serverctrls, response=response)
             else:
                 if self.module:
                     kwargs = {}
-                    if serverctrls and 'serverctrls' in getfullargspec(self.module.lookup).args:  # not every UDM handler supports serverctrls
+                    if serverctrls and 'serverctrls' in inspect.getfullargspec(self.module.lookup).args:  # not every UDM handler supports serverctrls
                         kwargs['serverctrls'] = serverctrls
                         kwargs['response'] = response
                     result = self.module.lookup(None, ldap_connection, filter_s, base=container, superordinate=superordinate, scope=scope, sizelimit=sizelimit, **kwargs)
@@ -926,7 +922,7 @@ class UDM_Module(object):
                     _scanLayout(ielement)
             elif isinstance(_layout, dict) and 'layout' in _layout:
                 _scanLayout(_layout['layout'])
-            elif isinstance(_layout, six.string_types):
+            elif isinstance(_layout, str):
                 inLayout.add(_layout)
         _scanLayout(self.get_layout(ldap_dn))
 
@@ -977,8 +973,8 @@ class UDM_Module(object):
 
             # default value
             if prop.base_default is not None:
-                if isinstance(prop.base_default, (list, tuple)):
-                    if prop.multivalue and prop.base_default and isinstance(prop.base_default[0], (list, tuple)):
+                if isinstance(prop.base_default, list | tuple):
+                    if prop.multivalue and prop.base_default and isinstance(prop.base_default[0], list | tuple):
                         item['default'] = prop.base_default
                     else:
                         item['default'] = prop.base_default[0]
@@ -1136,7 +1132,7 @@ class UDM_Module(object):
             if isinstance(syntax, udm_syntax.UDM_Objects) and syntax.key == 'dn' and len(syntax.udm_modules) == 1:
                 object_type = syntax.udm_modules[0]
                 dns = obj[key]
-                if not isinstance(dns, (list, tuple)):
+                if not isinstance(dns, list | tuple):
                     dns = [dns]
                 for dn in dns:
                     references.append({'module': 'udm', 'property': key, 'flavor': 'navigation', 'objectType': object_type, 'id': dn, 'label': '%s: %s: %s' % (key, object_type, dn), 'icon': 'udm-%s' % object_type.replace('/', '-')})
